@@ -6,7 +6,7 @@ from StringIO import StringIO
 from tempfile import TemporaryFile
 from Cookie import SimpleCookie
 
-from util import cache_property, make_traceback, list_obj_from_str
+from util import cache_property, make_traceback, obj_from_str, list_obj_from_str
 from config import cfg
 from exceptions import NotFound, Redirect, PermanentRedirect, BasicAuth
 from routing import auto_routing, add_apps
@@ -213,6 +213,7 @@ class App(object):
             **routing   - функция роутинга
         '''
         self.routing = routing or auto_routing
+        cfg_module = obj_from_str(cfg_module)
         if cfg_module:
             for k in cfg_module.__dict__.keys():
                 if not k.startswith('__') and k.isupper():
